/* Upgrade Story Tracker database from v1 to v2 */

begin exclusive transaction;

/* Update database version number */
update version set version_num = 2;

/* Copy existing data into new tables */
create table old_market as select * from market;
create table old_submission as select * from submission;

/* Drop old tables */
drop table market;
drop table submission;

/* Create new genre table */
CREATE TABLE genre (pk INTEGER PRIMARY KEY, name CHAR(100));

/* Create new market table with new notes, response time/units, word limit, pay-rate/units fields */
CREATE TABLE market (pk INTEGER PRIMARY KEY, title CHAR(100), genre CHAR(100), editor CHAR(100), address1 CHAR(100), address2 CHAR(100), address3 CHAR(100), url CHAR(100), email CHAR(100), phone CHAR(100), fax CHAR(100), open BOOLEAN, notes CHAR(255), responsetime INTEGER, responsetimeunits INTEGER, wordlimit INTEGER, payrate REAL, payrateunits INTEGER);

/* Create new submission table with new response due date and notes fields */
CREATE TABLE submission (pk INTEGER PRIMARY KEY, storykey INTEGER, marketkey INTEGER, sentdate REAL, response INTEGER, responsedate REAL, state INTEGER, income REAL, validduedate BOOLEAN, responseduedate REAL, notes CHAR(255));

/* Copy old data back into tables */
insert into market (pk, title, genre, editor, address1, address2, address3, url, email, phone, fax, open) select pk, title, genre, editor, address1, address2, address3, url, email, phone, fax, open from old_market;

insert into submission (pk, storykey, marketkey, sentdate, response, responsedate, state, income) select pk, storykey, marketkey, sentdate, response, responsedate, state, income from old_submission;

/* Remove temporary tables */
drop table old_market;
drop table old_submission;

commit;
